==> segatex-5.60.tgz: segatex-5.60/src/aureport.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2008 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qlayout.h>
#include <qpushbutton.h>

#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "aureport.h"
#include "aureport_process.h"

#include <iostream>
using namespace std;

//default constructor
Aureport::Aureport(QWidget *parent, const char *name): QDialog(parent, name)
{
	setCaption(tr("Aureport"));

        aureportLabel = new QLabel(tr("Report about"),this);
        optionButtonGroup = new QButtonGroup(this);
        optionButtonGroup->resize( 650, 350 );
        authenticationRadioButton = new QRadioButton(tr("authentication attempts"), optionButtonGroup);
        authenticationRadioButton->setGeometry( 10, 10, 400, 20 );//-au
        avcmessagesRadioButton = new QRadioButton(tr("avc messages"), optionButtonGroup);
        avcmessagesRadioButton->setGeometry( 10, 30, 400, 20 );//-a
        configRadioButton = new QRadioButton(tr("config changes"), optionButtonGroup);
        configRadioButton->setGeometry( 10, 50, 400, 20 );//-c
        cryptoRadioButton = new QRadioButton(tr("crypto events"), optionButtonGroup);
        cryptoRadioButton->setGeometry( 10, 70, 400, 20 );//-cr
        eventsRadioButton = new QRadioButton(tr("events"), optionButtonGroup);
        eventsRadioButton->setGeometry( 10, 90, 400, 20 );//-e
        filesRadioButton = new QRadioButton(tr("files"), optionButtonGroup);
        filesRadioButton->setGeometry( 10, 110, 400, 20 );//-f
        hostsRadioButton = new QRadioButton(tr("hosts"), optionButtonGroup);
        hostsRadioButton->setGeometry( 10, 130, 400, 20 );//-h
        loginRadioButton = new QRadioButton(tr("logins"), optionButtonGroup);
        loginRadioButton->setGeometry( 10, 150, 400, 20 );//-l
        modificationsRadioButton = new QRadioButton(tr("account modifications"), optionButtonGroup);
        modificationsRadioButton->setGeometry( 10, 170, 500, 20 );//-m
        macRadioButton = new QRadioButton(tr("Mandatory Access Control(MAC)events"), optionButtonGroup);
        macRadioButton->setGeometry( 10, 190, 400, 20 );//-mac
        pidRadioButton = new QRadioButton(tr("processes"), optionButtonGroup);
        pidRadioButton->setGeometry( 10, 210, 400, 20 );//-p
        responseRadioButton = new QRadioButton(tr("responses to anomaly events"), optionButtonGroup);
        responseRadioButton->setGeometry( 10, 230, 400, 20 );//-r
        syscallRadioButton = new QRadioButton(tr("syscalls"), optionButtonGroup);
        syscallRadioButton->setGeometry( 10, 250, 400, 20 );//-s
        terminalRadioButton = new QRadioButton(tr("terminals"), optionButtonGroup);
        terminalRadioButton->setGeometry( 10, 270, 400, 20 );//-tm
        userRadioButton = new QRadioButton(tr("user"), optionButtonGroup);
        userRadioButton->setGeometry( 10, 290, 400, 20 );//-u
        executableRadioButton = new QRadioButton(tr("executables"), optionButtonGroup);
        executableRadioButton->setGeometry( 10, 310, 400, 20 );//-e

        authenticationRadioButton->setChecked(true);

        option2ButtonGroup = new QButtonGroup(this);
        successFailedRadioButton = new QRadioButton(tr("Both successful and failed events"), option2ButtonGroup);
        successFailedRadioButton->setGeometry( 10, 10, 400, 20 );//no option
        successRadioButton = new QRadioButton(tr("Successful events"), option2ButtonGroup);
        successRadioButton->setGeometry( 10, 30, 400, 20 );//--success
        failedRadioButton = new QRadioButton(tr("Failed events"), option2ButtonGroup);
        failedRadioButton->setGeometry( 10, 50, 400, 20 );//--failed

        successFailedRadioButton->setChecked(true);

        summaryCheckBox = new QCheckBox(tr("Run the summary report of the main report"), this);
        //summaryCheckBox->setGeometry( 10, 10, 400, 20 );//--summary

        interpretCheckBox = new QCheckBox(tr("Interpret numeric entities into text"), this);
        //interpretCheckBox->setGeometry( 10, 10, 400, 20 );//-i
/*
        nodeCheckBox = new QCheckBox(tr(" Select events all nodes for processing in the reports."), this);
        nodeCheckBox->setGeometry( 10, 10, 400, 20 );//--node
*/

	aureportButton = new QPushButton(tr("See report"), this);
	aureportButton->setPaletteBackgroundColor(QColor(250,180,200));
	connect(aureportButton, SIGNAL(clicked()), this, SLOT(aureport_button_clicked()));


	closeButton = new QPushButton(tr("close"), this);
	//closing process button
	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
	closeButton->setDefault(true);

	mainLayout = new QVBoxLayout(this);
	middleLayout = new QVBoxLayout;
	firstLayout = new QHBoxLayout;
	secondLayout = new QVBoxLayout;
	thirdLayout = new QVBoxLayout;
	fourthLayout = new QHBoxLayout;
	footLayout = new QHBoxLayout;
	
	mainLayout->setMargin(11);
	secondLayout->addWidget(aureportLabel);
	secondLayout->addWidget(optionButtonGroup);
	thirdLayout->addStretch();
	thirdLayout->addWidget(option2ButtonGroup);
	thirdLayout->addWidget(summaryCheckBox);
	thirdLayout->addWidget(interpretCheckBox);
	//thirdLayout->addWidget(nodeCheckBox);
	fourthLayout->addStretch();
	fourthLayout->addWidget(aureportButton);
	fourthLayout->addStretch();

	firstLayout->addLayout(secondLayout);
	firstLayout->addLayout(thirdLayout);
	middleLayout->addLayout(firstLayout);
	middleLayout->addLayout(fourthLayout);

	footLayout->addStretch();
	footLayout->addWidget(closeButton);

	//mainLayout->addLayout(upperLayout);
	mainLayout->addLayout(middleLayout);
	mainLayout->addLayout(footLayout);

	aureport_process = 0;

	resize(1000,480);
}

/*signal and slot should have same argument pattern so I had to pass to another slot*/
void Aureport::aureport_button_clicked()
{
	if(authenticationRadioButton->isChecked())
		aureport_str_pp = "aureport -au";
	if(avcmessagesRadioButton->isChecked())
		aureport_str_pp = "aureport -a";
	if(configRadioButton->isChecked())
		aureport_str_pp = "aureport -c";
	if(cryptoRadioButton->isChecked())
		aureport_str_pp = "aureport -cr";
	if(eventsRadioButton->isChecked())
		aureport_str_pp = "aureport -e";
	if(filesRadioButton->isChecked())
		aureport_str_pp = "aureport -f";
	if(hostsRadioButton->isChecked())
		aureport_str_pp = "aureport -h";
	if(loginRadioButton->isChecked())
		aureport_str_pp = "aureport -l";
	if(modificationsRadioButton->isChecked())
		aureport_str_pp = "aureport -m";
	if(macRadioButton->isChecked())
		aureport_str_pp = "aureport -ma";
	if(pidRadioButton->isChecked())
		aureport_str_pp = "aureport -p";
	if(responseRadioButton->isChecked())
		aureport_str_pp = "aureport -r";
	if(syscallRadioButton->isChecked())
		aureport_str_pp = "aureport -s";
	if(terminalRadioButton->isChecked())
		aureport_str_pp = "aureport -tm";
	if(userRadioButton->isChecked())
		aureport_str_pp = "aureport -u";
	if(executableRadioButton->isChecked())
		aureport_str_pp = "aureport -x";

	if(failedRadioButton->isChecked())
		aureport_str_pp = aureport_str_pp + " --failed";
	if(successRadioButton->isChecked())
		aureport_str_pp = aureport_str_pp + " --success";

	if(summaryCheckBox->isChecked())
		aureport_str_pp = aureport_str_pp + " --summary";
	if(interpretCheckBox->isChecked())
		aureport_str_pp = aureport_str_pp + " -i";
/*
	if(nodeCheckBox->isChecked())
		aureport_str_pp = aureport_str_pp + " --node";
*/

	aureport_str_pp_str = aureport_str_pp;
	aureport_process = new AureportProcess(this);
	//connect(aureport_process, SIGNAL(aureport_process_close_button_clicked()), this, SLOT(close()));
	connect(closeButton, SIGNAL(clicked()), aureport_process, SLOT(close()));
	aureport_process->setCaption(tr(aureport_str_pp_str));
	aureport_process->show();
	aureport_process->raise();
	aureport_process->setActiveWindow();

	aureport_process->aureport_base_process(aureport_str_pp_str);

}

==> segatex-6.80.tgz: segatex-6.80/src/aureport.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2008 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qlayout.h>
#include <qpushbutton.h>
#include <qlineedit.h>

#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "aureport.h"
#include "aureport_process.h"

#include <iostream>
using namespace std;

//default constructor
Aureport::Aureport(QWidget *parent, const char *name): QDialog(parent, name)
{
	setCaption(tr("Aureport"));

        aureportLabel = new QLabel(tr("Report about"),this);
        startdayLabel = new QLabel(tr("start-day(1/1/2008)"),this);
        starttimeLabel = new QLabel(tr("start-time"),this);
        enddayLabel = new QLabel(tr("end-day"),this);
        endtimeLabel = new QLabel(tr("end-time"),this);

        optionButtonGroup = new QButtonGroup(this);
        optionButtonGroup->resize( 650, 350 );
        authenticationRadioButton = new QRadioButton(tr("authentication attempts"), optionButtonGroup);
        authenticationRadioButton->setGeometry( 10, 10, 400, 20 );//-au
        avcmessagesRadioButton = new QRadioButton(tr("avc messages"), optionButtonGroup);
        avcmessagesRadioButton->setGeometry( 10, 30, 400, 20 );//-a
        configRadioButton = new QRadioButton(tr("config changes"), optionButtonGroup);
        configRadioButton->setGeometry( 10, 50, 400, 20 );//-c
        cryptoRadioButton = new QRadioButton(tr("crypto events"), optionButtonGroup);
        cryptoRadioButton->setGeometry( 10, 70, 400, 20 );//-cr
        eventsRadioButton = new QRadioButton(tr("events"), optionButtonGroup);
        eventsRadioButton->setGeometry( 10, 90, 400, 20 );//-e
        filesRadioButton = new QRadioButton(tr("files"), optionButtonGroup);
        filesRadioButton->setGeometry( 10, 110, 400, 20 );//-f
        hostsRadioButton = new QRadioButton(tr("hosts"), optionButtonGroup);
        hostsRadioButton->setGeometry( 10, 130, 400, 20 );//-h
        loginRadioButton = new QRadioButton(tr("logins"), optionButtonGroup);
        loginRadioButton->setGeometry( 10, 150, 400, 20 );//-l
        modificationsRadioButton = new QRadioButton(tr("account modifications"), optionButtonGroup);
        modificationsRadioButton->setGeometry( 10, 170, 500, 20 );//-m
        macRadioButton = new QRadioButton(tr("Mandatory Access Control(MAC)events"), optionButtonGroup);
        macRadioButton->setGeometry( 10, 190, 400, 20 );//-mac
        pidRadioButton = new QRadioButton(tr("processes"), optionButtonGroup);
        pidRadioButton->setGeometry( 10, 210, 400, 20 );//-p
        responseRadioButton = new QRadioButton(tr("responses to anomaly events"), optionButtonGroup);
        responseRadioButton->setGeometry( 10, 230, 400, 20 );//-r
        syscallRadioButton = new QRadioButton(tr("syscalls"), optionButtonGroup);
        syscallRadioButton->setGeometry( 10, 250, 400, 20 );//-s
        terminalRadioButton = new QRadioButton(tr("terminals"), optionButtonGroup);
        terminalRadioButton->setGeometry( 10, 270, 400, 20 );//-tm
        userRadioButton = new QRadioButton(tr("user"), optionButtonGroup);
        userRadioButton->setGeometry( 10, 290, 400, 20 );//-u
        executableRadioButton = new QRadioButton(tr("executables"), optionButtonGroup);
        executableRadioButton->setGeometry( 10, 310, 400, 20 );//-e

        authenticationRadioButton->setChecked(true);

        option2ButtonGroup = new QButtonGroup(this);
        successFailedRadioButton = new QRadioButton(tr("Both successful and failed events"), option2ButtonGroup);
        successFailedRadioButton->setGeometry( 10, 10, 400, 20 );//no option
        successRadioButton = new QRadioButton(tr("Successful events"), option2ButtonGroup);
        successRadioButton->setGeometry( 10, 30, 400, 20 );//--success
        failedRadioButton = new QRadioButton(tr("Failed events"), option2ButtonGroup);
        failedRadioButton->setGeometry( 10, 50, 400, 20 );//--failed

        successFailedRadioButton->setChecked(true);

        summaryCheckBox = new QCheckBox(tr("Run the summary report of the main report"), this);
        //summaryCheckBox->setGeometry( 10, 10, 400, 20 );//--summary

        interpretCheckBox = new QCheckBox(tr("Interpret numeric entities into text"), this);
        //interpretCheckBox->setGeometry( 10, 10, 400, 20 );//-i
/*
        nodeCheckBox = new QCheckBox(tr(" Select events all nodes for processing in the reports."), this);
        nodeCheckBox->setGeometry( 10, 10, 400, 20 );//--node
*/

	aureportButton = new QPushButton(tr("See report"), this);
	aureportButton->setPaletteBackgroundColor(QColor(250,180,200));
	connect(aureportButton, SIGNAL(clicked()), this, SLOT(aureport_button_clicked()));


	closeButton = new QPushButton(tr("close"), this);
	//closing process button
	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
	closeButton->setDefault(true);

        startdayEditLineEdit = new QLineEdit( this );
        startdayEditLineEdit->setText("this-year");
        startdayEditLineEdit->setPaletteBackgroundColor(QColor(200,200,140));

        starttimeEditLineEdit = new QLineEdit( this );
        starttimeEditLineEdit->setText("04:00:00");
        starttimeEditLineEdit->setPaletteBackgroundColor(QColor(200,200,140));

        enddayEditLineEdit = new QLineEdit( this );
        enddayEditLineEdit->setText("today");
        enddayEditLineEdit->setPaletteBackgroundColor(QColor(200,200,140));

        endtimeEditLineEdit = new QLineEdit( this );
        endtimeEditLineEdit->setText("");
        endtimeEditLineEdit->setPaletteBackgroundColor(QColor(200,200,140));

	mainLayout = new QVBoxLayout(this);
	middleLayout = new QVBoxLayout;
	firstLayout = new QHBoxLayout;
	secondLayout = new QVBoxLayout;
	thirdLayout = new QVBoxLayout;
	tirsharyLayout = new QHBoxLayout;
	quadroLayout = new QHBoxLayout;
	fourthLayout = new QHBoxLayout;
	footLayout = new QHBoxLayout;
	
	mainLayout->setMargin(11);
	secondLayout->addWidget(aureportLabel);
	secondLayout->addWidget(optionButtonGroup);
	thirdLayout->addStretch();
	thirdLayout->addWidget(option2ButtonGroup);
	thirdLayout->addWidget(summaryCheckBox);
	thirdLayout->addWidget(interpretCheckBox);
	tirsharyLayout->addWidget(startdayLabel);
	tirsharyLayout->addWidget(startdayEditLineEdit);
	tirsharyLayout->addWidget(starttimeLabel);
	tirsharyLayout->addWidget(starttimeEditLineEdit);
	quadroLayout->addWidget(enddayLabel);
	quadroLayout->addWidget(enddayEditLineEdit);
	quadroLayout->addWidget(endtimeLabel);
	quadroLayout->addWidget(endtimeEditLineEdit);
	//thirdLayout->addWidget(nodeCheckBox);
	fourthLayout->addStretch();
	fourthLayout->addWidget(aureportButton);
	fourthLayout->addStretch();

	thirdLayout->addLayout(tirsharyLayout);
	thirdLayout->addLayout(quadroLayout);
	firstLayout->addLayout(secondLayout);
	firstLayout->addLayout(thirdLayout);
	middleLayout->addLayout(firstLayout);
	middleLayout->addLayout(fourthLayout);

	footLayout->addStretch();
	footLayout->addWidget(closeButton);

	//mainLayout->addLayout(upperLayout);
	mainLayout->addLayout(middleLayout);
	mainLayout->addLayout(footLayout);

	aureport_process = 0;

	resize(1000,480);
}

/*signal and slot should have same argument pattern so I had to pass to another slot*/
void Aureport::aureport_button_clicked()
{
	if(authenticationRadioButton->isChecked())
		aureport_str_pp = "aureport -au";
	if(avcmessagesRadioButton->isChecked())
		aureport_str_pp = "aureport -a";
	if(configRadioButton->isChecked())
		aureport_str_pp = "aureport -c";
	if(cryptoRadioButton->isChecked())
		aureport_str_pp = "aureport -cr";
	if(eventsRadioButton->isChecked())
		aureport_str_pp = "aureport -e";
	if(filesRadioButton->isChecked())
		aureport_str_pp = "aureport -f";
	if(hostsRadioButton->isChecked())
		aureport_str_pp = "aureport -h";
	if(loginRadioButton->isChecked())
		aureport_str_pp = "aureport -l";
	if(modificationsRadioButton->isChecked())
		aureport_str_pp = "aureport -m";
	if(macRadioButton->isChecked())
		aureport_str_pp = "aureport -ma";
	if(pidRadioButton->isChecked())
		aureport_str_pp = "aureport -p";
	if(responseRadioButton->isChecked())
		aureport_str_pp = "aureport -r";
	if(syscallRadioButton->isChecked())
		aureport_str_pp = "aureport -s";
	if(terminalRadioButton->isChecked())
		aureport_str_pp = "aureport -tm";
	if(userRadioButton->isChecked())
		aureport_str_pp = "aureport -u";
	if(executableRadioButton->isChecked())
		aureport_str_pp = "aureport -x";

	if(failedRadioButton->isChecked())
		aureport_str_pp = aureport_str_pp + " --failed";
	if(successRadioButton->isChecked())
		aureport_str_pp = aureport_str_pp + " --success";

	if(summaryCheckBox->isChecked())
		aureport_str_pp = aureport_str_pp + " --summary";
	if(interpretCheckBox->isChecked())
		aureport_str_pp = aureport_str_pp + " -i";
/*
	if(nodeCheckBox->isChecked())
		aureport_str_pp = aureport_str_pp + " --node";
*/

	aureport_str_pp_str = aureport_str_pp;

	//set start-day and start-time
	startdayEditLineEdit_str = startdayEditLineEdit->text();
	starttimeEditLineEdit_str = starttimeEditLineEdit->text();
	if(startdayEditLineEdit_str != ""){
		aureport_str_pp_str = aureport_str_pp_str + " --start " + startdayEditLineEdit_str + " " + starttimeEditLineEdit_str;
	}
	//set end-day and end-time
	enddayEditLineEdit_str = enddayEditLineEdit->text();
	endtimeEditLineEdit_str = endtimeEditLineEdit->text();
	if(enddayEditLineEdit_str != ""){
		aureport_str_pp_str = aureport_str_pp_str + " --end " + enddayEditLineEdit_str + " " + endtimeEditLineEdit_str;
	}

	aureport_process = new AureportProcess(this);
	//connect(aureport_process, SIGNAL(aureport_process_close_button_clicked()), this, SLOT(close()));
	connect(closeButton, SIGNAL(clicked()), aureport_process, SLOT(close()));
	aureport_process->setCaption(tr(aureport_str_pp_str));
	aureport_process->show();
	aureport_process->raise();
	aureport_process->setActiveWindow();

	aureport_process->aureport_base_process(aureport_str_pp_str);

}
